@@ -9,8 +9,12 @@
    archives. */
 
 #ifdef PNG_sCAL_SUPPORTED
-#if PNG_LIBPNG_VER_MINOR > 4 || defined (PNG_FIXED_POINT_SUPPORTED)
-#define PNG_sCAL_REALLY_SUPPORTED
+#if PNG_LIBPNG_VER_MINOR > 4 ||						\
+    (defined (PNG_FIXED_POINT_SUPPORTED) &&  PNG_LIBPNG_VER_MINOR > 2)	\
+    || (PNG_LIBPNG_VER_MINOR == 2 &&					\
+	defined (PNG_FIXED_POINT_SUPPORTED) &&				\
+	! defined (PNG_FLOATING_POINT_SUPPORTED))
+#define PNG_sCAL_s_SUPPORTED
 #endif /* version or fixed point */
 #endif /* PNG_sCAL_SUPPORTED */
 
@@ -1445,7 +1449,7 @@ static void perl_png_set_tRNS_pointer (perl_libpng_t * png, png_bytep trans, int
 
 static SV * perl_png_get_sCAL (perl_libpng_t * png)
 {
-#ifdef PNG_sCAL_REALLY_SUPPORTED
+#ifdef PNG_sCAL_s_SUPPORTED
     if (VALID (sCAL)) {
         HV * ice;
 	int unit;
@@ -1459,15 +1463,15 @@ static SV * perl_png_get_sCAL (perl_libpng_t * png)
         return newRV_inc ((SV *) ice);
     }
     UNDEF;
-#else /* PNG_sCAL_REALLY_SUPPORTED */
+#else /* PNG_sCAL_s_SUPPORTED */
     perl_png_warn (png, "sCAL chunk not supported in this libpng");
     UNDEF;
-#endif /* PNG_sCAL_REALLY_SUPPORTED */
+#endif /* PNG_sCAL_s_SUPPORTED */
 }
 
 static void perl_png_set_sCAL (perl_libpng_t * png, HV * sCAL)
 {
-#ifdef PNG_sCAL_REALLY_SUPPORTED
+#ifdef PNG_sCAL_s_SUPPORTED
     int unit;
     char * width;
     char * height;
@@ -1477,9 +1481,9 @@ static void perl_png_set_sCAL (perl_libpng_t * png, HV * sCAL)
     HASH_FETCH_PV (sCAL, width);
     HASH_FETCH_PV (sCAL, height);
     png_set_sCAL_s (pngi, unit, width, height);
-#else /* PNG_sCAL_REALLY_SUPPORTED */
+#else /* PNG_sCAL_s_SUPPORTED */
     perl_png_warn (png, "sCAL chunk not supported in this libpng");
-#endif /* PNG_sCAL_REALLY_SUPPORTED */
+#endif /* PNG_sCAL_s_SUPPORTED */
 }
 
 static void perl_png_set_hIST (perl_libpng_t * png, AV * hIST)
@@ -2051,7 +2055,7 @@ int perl_png_libpng_supports (const char * what)
 #endif /* tEXt */
     }
     if (strcmp (what, "sCAL") == 0) {
-#ifdef PNG_sCAL_REALLY_SUPPORTED
+#ifdef PNG_sCAL_s_SUPPORTED
         return 1;
 #else
         return 0;
